MacroResolver class

Constructors

MacroResolver()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

isRobloxType(DartType? type) bool
resolveMethod(DartType? type, String method, String target, List<String> args) String?
resolveProperty(DartType? type, String property, String target) String?
resolveStaticProperty(String typeName, String property) String?