LuauFunction class
Constructors
-
LuauFunction({required String name, required List<
LuauNode> body, List<LuauParameter> parameters = const [], String? returnType, bool isLocal = false})
Properties
-
body
→ List<
LuauNode> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isLocal → bool
-
final
- name → String
-
final
-
parameters
→ List<
LuauParameter> -
final
- returnType → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
emit(
{int indent = 0}) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited