LuauMethod class

Inheritance

Constructors

LuauMethod({required String className, required String methodName, required List<LuauParameter> parameters, required List<LuauNode> body, bool isStatic = false})

Properties

body List<LuauNode>
final
className String
final
hashCode int
The hash code for this object.
no setterinherited
isStatic bool
final
methodName String
final
parameters List<LuauParameter>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

emit({int indent = 0}) String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited