LuauAssignmentExpression class

Inheritance

Constructors

LuauAssignmentExpression({required LuauNode left, required String operator, required LuauNode right})

Properties

hashCode int
The hash code for this object.
no setterinherited
left LuauNode
final
operator String
final
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

emit({int indent = 0}) String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited