LuauNode class abstract
- Implementers
- LuauAnonymousFunction
- LuauAssignmentExpression
- LuauBinaryExpression
- LuauCallExpression
- LuauClass
- LuauConditionalExpression
- LuauConstructor
- LuauContinueStatement
- LuauDoStatement
- LuauEnum
- LuauExpressionStatement
- LuauForInStatement
- LuauForStatement
- LuauFunction
- LuauFunctionInvocation
- LuauIfStatement
- LuauIndexExpression
- LuauListLiteral
- LuauLiteral
- LuauMapLiteral
- LuauMethod
- LuauNumericForStatement
- LuauPairForEach
- LuauReturnStatement
- LuauTryCatch
- LuauVariableDeclaration
- LuauVariableDeclarationGroup
- LuauWhileStatement
Constructors
- LuauNode()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
emit(
{int indent = 0}) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited