LuauForInStatement class

Inheritance

Constructors

LuauForInStatement({required String itemName, required LuauNode list, required List<LuauNode> body, bool usePairs = false})

Properties

body List<LuauNode>
final
hashCode int
The hash code for this object.
no setterinherited
itemName String
final
list LuauNode
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
usePairs bool
final

Methods

emit({int indent = 0}) String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited