LuauForStatement class

Inheritance

Constructors

LuauForStatement({LuauNode? initializer, LuauNode? condition, List<LuauNode> updaters = const [], required List<LuauNode> body})

Properties

body List<LuauNode>
final
condition LuauNode?
final
hashCode int
The hash code for this object.
no setterinherited
initializer LuauNode?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updaters List<LuauNode>
final

Methods

emit({int indent = 0}) String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited