LuauNumericForStatement class

Inheritance

Constructors

LuauNumericForStatement({required String variable, required LuauNode start, required LuauNode end, LuauNode? step, required List<LuauNode> body})

Properties

body List<LuauNode>
final
end LuauNode
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start LuauNode
final
step LuauNode?
final
variable String
final

Methods

emit({int indent = 0}) String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited