LuauVariableDeclaration class

Inheritance

Constructors

LuauVariableDeclaration({required String name, String? type, LuauNode? initializer})

Properties

hashCode int
The hash code for this object.
no setterinherited
initializer LuauNode?
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
final

Methods

emit({int indent = 0}) String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited