LuauVariableDeclarationGroup class

Inheritance

Constructors

LuauVariableDeclarationGroup({required List<LuauVariableDeclaration> declarations})

Properties

declarations List<LuauVariableDeclaration>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

emit({int indent = 0}) String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited