CFrame class

Constructors

CFrame(double x, double y, double z)

Properties

hashCode int
The hash code for this object.
no setterinherited
lookVector Vector3
no setter
position Vector3
no setter
rightVector Vector3
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
upVector Vector3
no setter
x double
no setter
y double
no setter
z double
no setter

Methods

inverse() CFrame
lerp(CFrame goal, double alpha) CFrame
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pointToObjectSpace(Vector3 v) Vector3
pointToWorldSpace(Vector3 v) Vector3
toObjectSpace(CFrame cf) CFrame
toString() String
A string representation of this object.
inherited
toWorldSpace(CFrame cf) CFrame

Operators

operator *(CFrame other) CFrame
operator +(Vector3 other) CFrame
operator -(Vector3 other) CFrame
operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromEulerAnglesXYZ(double rx, double ry, double rz) CFrame
lookAt(Vector3 at, Vector3 lookAt) CFrame