Humanoid class

Inheritance

Constructors

Humanoid()
factory

Properties

className String
getter/setter pairinherited
displayName String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
health double
getter/setter pair
jumpHeight double
getter/setter pair
jumpPower double
getter/setter pair
maxHealth double
getter/setter pair
name String
getter/setter pairinherited
parent Instance?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
walkSpeed double
getter/setter pair

Methods

changeState(int state) → void
clone() Instance
inherited
destroy() → void
inherited
findFirstAncestorOfClass(String className) Instance?
inherited
findFirstChild(String name, [bool recursive]) Instance?
inherited
findFirstChildOfClass(String className) Instance?
inherited
findFirstChildWhichIsA(String className) Instance?
inherited
findFirstDescendant(String name) Instance?
inherited
getChildren() List<Instance>
inherited
getDescendants() List<Instance>
inherited
getFullName() String
inherited
isA(String className) bool
inherited
isAncestorOf(Instance descendant) bool
inherited
isDead() bool
isDescendantOf(Instance ancestor) bool
inherited
moveTo(Vector3 position) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
takeDamage(double amount) → void
toString() String
A string representation of this object.
inherited
waitForChild(String name, [double? timeOut]) Instance
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited