Instance class

Implementers

Constructors

Instance(String className, [bool recursive])

Properties

className String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String
getter/setter pair
parent Instance?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clone() Instance
destroy() → void
findFirstAncestorOfClass(String className) Instance?
findFirstChild(String name, [bool recursive]) Instance?
findFirstChildOfClass(String className) Instance?
findFirstChildWhichIsA(String className) Instance?
findFirstDescendant(String name) Instance?
getChildren() List<Instance>
getDescendants() List<Instance>
getFullName() String
isA(String className) bool
isAncestorOf(Instance descendant) bool
isDescendantOf(Instance ancestor) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
waitForChild(String name, [double? timeOut]) Instance

Operators

operator ==(Object other) bool
The equality operator.
inherited