Part class

Inheritance

Constructors

Part()

Properties

anchored bool
getter/setter pairinherited
canCollide bool
getter/setter pairinherited
castShadow bool
getter/setter pairinherited
cFrame CFrame
getter/setter pairinherited
className String
getter/setter pairinherited
color Color3
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
massless bool
getter/setter pairinherited
name String
getter/setter pairinherited
parent Instance?
getter/setter pairinherited
position Vector3
getter/setter pairinherited
rotVelocity Vector3
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size Vector3
getter/setter pairinherited
touched RBXScriptSignal<dynamic Function(BasePart)>
no setterinherited
touchEnded RBXScriptSignal<dynamic Function(BasePart)>
no setterinherited
transparency double
getter/setter pairinherited
velocity Vector3
getter/setter pairinherited

Methods

applyAngularImpulse(Vector3 impulse) → void
inherited
applyImpulse(Vector3 impulse) → void
inherited
clone() Instance
inherited
destroy() → void
inherited
findFirstAncestorOfClass(String className) Instance?
inherited
findFirstChild(String name, [bool recursive]) Instance?
inherited
findFirstChildOfClass(String className) Instance?
inherited
findFirstChildWhichIsA(String className) Instance?
inherited
findFirstDescendant(String name) Instance?
inherited
getChildren() List<Instance>
inherited
getDescendants() List<Instance>
inherited
getFullName() String
inherited
getVelocityAtPosition(Vector3 position) Vector3
inherited
isA(String className) bool
inherited
isAncestorOf(Instance descendant) bool
inherited
isDescendantOf(Instance ancestor) bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
waitForChild(String name, [double? timeOut]) Instance
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited