UDim2 class

Constructors

UDim2(double xScale, double xOffset, double yScale, double yOffset)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x double
no setter
y double
no setter

Methods

lerp(UDim2 goal, double alpha) UDim2
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromOffset(double x, double y) UDim2
fromScale(double x, double y) UDim2