ParameterResult class
Constructors
-
ParameterResult(List<
LuauParameter> fnParams, List<LuauNode> unpackers, List<LuauNode> fieldAssignments, bool hasNamed)
Properties
-
fieldAssignments
→ List<
LuauNode> -
final
-
fnParams
→ List<
LuauParameter> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasNamed → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
unpackers
→ List<
LuauNode> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited