LuauClass class
Constructors
Properties
-
constructors
→ List<
LuauNode> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
methods
→ List<
LuauNode> -
final
-
mixinInjections
→ List<
LuauNode> -
final
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
staticFields
→ List<
LuauNode> -
final
- superClassName → String?
-
final
Methods
-
emit(
{int indent = 0}) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited