Workspace class
Constructors
- Workspace()
-
factory
Properties
- className ↔ String
-
getter/setter pairinherited
- currentCamera ↔ Instance?
-
getter/setter pair
- gravity ↔ double
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String
-
getter/setter pairinherited
- parent ↔ Instance?
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- streamingEnabled → bool
-
no setter
- terrain → Instance
-
no setter
Methods
-
clone(
) → Instance -
inherited
-
destroy(
) → void -
inherited
-
findFirstAncestorOfClass(
String className) → Instance? -
inherited
-
findFirstChild(
String name, [bool recursive]) → Instance? -
inherited
-
findFirstChildOfClass(
String className) → Instance? -
inherited
-
findFirstChildWhichIsA(
String className) → Instance? -
inherited
-
findFirstDescendant(
String name) → Instance? -
inherited
-
getChildren(
) → List< Instance> -
inherited
-
getDescendants(
) → List< Instance> -
inherited
-
getFullName(
) → String -
inherited
-
isA(
String className) → bool -
inherited
-
isAncestorOf(
Instance descendant) → bool -
inherited
-
isDescendantOf(
Instance ancestor) → bool -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
waitForChild(
String name, [double? timeOut]) → Instance -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited